#!/bin/bash

if [ "$(whoami)" == "probotix" ]
then
	# push password into sudo so that it doesnt prompt for it later
	sudo -S <<< "probotix" clear
else
	echo "Not running as user probotix! Call PROBOTIX 844.472.9262"
	sleep 10
	exit
fi

# remove previous configs backup
rm -Rf /home/probotix/linuxcnc_old
# backup current configs
mv /home/probotix/linuxcnc /home/probotix/linuxcnc_old
# remove and recreate linuxcnc dir
rm -Rf /home/probotix/linuxcnc
rm -Rf /home/probotix/Desktop/*.desktop
mkdir -p /home/probotix/linuxcnc/configs/Probotix_2015
mkdir -p /home/probotix/linuxcnc/nc_files

# choose machine link for LinuxCNC on desktop
echo "Which Machine Configuration would you like to install?"
select machine in "V90MK2" "V90MK2_VFD" "Asteroid" "Asteroid_VFD" "Comet" "Comet_VFD" "Meteor" "Meteor_VFD" "Nebula" "Nebula_VFD"; 
do
    case $machine in
		V90MK2 ) cp ./Desktop_Icons/V90MK2_2015.desktop /home/probotix/Desktop/; break;;
		V90MK2_VFD ) cp ./Desktop_Icons/V90MK2_VFD_2015.desktop /home/probotix/Desktop/; break;;
		Asteroid ) cp ./Desktop_Icons/Asteroid_2015.desktop /home/probotix/Desktop/; break;;
		Asteroid_VFD ) cp ./Desktop_Icons/Asteroid_VFD_2015.desktop /home/probotix/Desktop/; break;;
		Comet ) cp ./Desktop_Icons/Comet_2015.desktop /home/probotix/Desktop/; break;;
		Comet_VFD ) cp ./Desktop_Icons/Comet_VFD_2015.desktop /home/probotix/Desktop/; break;;
		Meteor ) cp ./Desktop_Icons/Meteor_2015.desktop /home/probotix/Desktop/; break;;
		Meteor_VFD ) cp ./Desktop_Icons/Meteor_VFD_2015.desktop /home/probotix/Desktop/; break;;
		Nebula ) cp ./Desktop_Icons/Nebula_2015.desktop /home/probotix/Desktop/; break;;
        Nebula_VFD ) cp ./Desktop_Icons/Nebula_VFD_2015.desktop /home/probotix/Desktop/; break;;
    esac
done

# copy config files to linuxcnc dir
cp -Rud ./Probotix_Unity_Conversion/* /home/probotix/linuxcnc/configs/Probotix_2015

# restore original axis files
sudo rm -f /usr/bin/axis
sudo rm -Rf /usr/share/axis
sudo cp -Rf ./.axis_orig/usr/* /usr/
sudo chmod 755 -R /usr/share/axis

# remove update-manager to prevent breaking linuxcnc
sudo apt-get remove -y update-manager

# copy nc_files to linuxcnc dir
cp -rf ./nc_files/* /home/probotix/linuxcnc/nc_files/
# create link to nc_files on desktop
ln -sf /home/probotix/linuxcnc/nc_files/ /home/probotix/Desktop/nc_files
# copy wallpaper
cp ./background.png /home/probotix/Pictures/

# set wallpaper
gconftool-2 -t string -s /desktop/gnome/background/picture_filename /home/probotix/Pictures/background.png
# disable screen saver/idle
gconftool-2 --type bool --set /apps/gnome-screensaver/lock_enabled 0
gconftool-2 --type bool --set /apps/gnome-screensaver/idle_activation_enabled 0
# enable line numbers in gedit
gconftool-2 --type bool --set /apps/gedit-2/preferences/editor/line_numbers/display_line_numbers true

###################################################################################################
# 	this section tries to identify the add-on parallel port address
#
LSPCI=$(lspci -v | grep NetMos)
if [ -z "$LSPCI" ]
then
	echo "SECOND PARALLEL PORT NOT FOUND"
fi

# capture output of lscpi and copy it to file on the thumb drive so customer can email it if necessary
rm -rf ./LSPCI.txt
lspci -v > ./LSPCI.txt

# get substring
SUB=${LSPCI:0:7}
ADDR=$(dmesg | grep $SUB)
A=${ADDR#*0x}
B=${A:0:4}
# hopefully this will be the variable for the second parallel port
IDENT="0x"$B
LEN=${#IDENT}

if [ $LEN -eq 6 ]
then
	IDENTB=$IDENT
else
	IDENTB="0xd050"
fi

PARPORT0="0x378"
PARPORT1=$IDENTB

# save parports to hal file
echo "set parport addr in hal file"
sed -i -e 's/PARPORT0/'"$PARPORT0"'/' \
	-e 's/PARPORT1/'"$PARPORT1"'/' /home/probotix/linuxcnc/configs/Probotix_2015/Probotix.hal
sed -i -e 's/PARPORT0/'"$PARPORT0"'/' \
	-e 's/PARPORT1/'"$PARPORT1"'/' /home/probotix/linuxcnc/configs/Probotix_2015/Probotix_VFD.hal

###################################################################################################

echo "The PC will now restart in 5 seconds."
echo "Please ensure the Unity Controller is powered OFF."
echo
echo "If you do not wish to reset at this time press CTRL+C to cancel."

sleep 5

sudo shutdown -r now

